﻿using Infragistics.Win;
using Infragistics.Win.UltraWinSchedule.DayView;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace WindowsFormsApplication47
{
    class MyCreationFilter : IUIElementCreationFilter
    {
        void IUIElementCreationFilter.AfterCreateChildElements(UIElement parent)
        {
            if (parent is HeadingAreaUIElement)
            {
                var dayHeaderAreaUIElement = parent.GetDescendant(typeof(DayHeaderAreaUIElement));
                if (null == dayHeaderAreaUIElement)
                    return;

                var allDayEventAreaUIElement = parent.GetDescendant(typeof(AllDayEventAreaUIElement));
                if (null == allDayEventAreaUIElement)
                    return;

                // We don't really need to do anything with this element, but we will use
                // it's height to determine the height of the new headers we are adding. 
                var dayHeaderUIElement = dayHeaderAreaUIElement.GetDescendant(typeof(DayHeaderUIElement)) as DayHeaderUIElement;
                if (null == dayHeaderUIElement)
                    return;

                int headerHeight = dayHeaderUIElement.Rect.Height;
                Debug.WriteLine(headerHeight, dayHeaderUIElement.Date.ToShortDateString());

                // Increase the Height of the DayHeaderAreaUIElement
                Rectangle dayHeaderAreaRect = dayHeaderAreaUIElement.Rect;
                dayHeaderAreaUIElement.Rect = new System.Drawing.Rectangle(
                    dayHeaderAreaRect.X,
                    dayHeaderAreaRect.Y,
                    dayHeaderAreaRect.Width,
                    dayHeaderAreaRect.Height + headerHeight
                    );

                // Shift the AllDayEventArea down to make room for the extra height
                // of the dayHeaderAreaUIElement.
                Rectangle allDayEventAreaRect = allDayEventAreaUIElement.Rect;
                allDayEventAreaUIElement.Rect = new Rectangle(
                    allDayEventAreaRect.X,
                    allDayEventAreaRect.Y + headerHeight,
                    allDayEventAreaRect.Width,
                    allDayEventAreaRect.Height - headerHeight
                    );
            }
            else if (parent is DayHeaderAreaUIElement)
            {
                foreach (var childElement in parent.ChildElements)
                {
                    var dayHeaderUIElement = childElement as DayHeaderUIElement;
                    if (null == dayHeaderUIElement)
                        continue;

                    var newHeader = new MyDayHeaderUIElement(parent);
                    newHeader.Rect = new Rectangle(
                        dayHeaderUIElement.Rect.X,
                        dayHeaderUIElement.Rect.Bottom,
                        dayHeaderUIElement.Rect.Width,
                        dayHeaderUIElement.Rect.Height
                        );

                    parent.ChildElements.Add(newHeader);
                }
            }
        }

        bool IUIElementCreationFilter.BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}
